__title__ = "srsly"
__version__ = "1.0.5"
__summary__ = "Modern high-performance serialization utilities for Python"
__uri__ = "https://explosion.ai"
__author__ = "Explosion AI"
__email__ = "contact@explosion.ai"
__license__ = "MIT"
